@@ -4,14 +4,24 @@
 ( cd opt/kde/share/doc/HTML/nl/kate ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/ksysguard ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/crashes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/babel ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kfind ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kuick ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/klipper ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/webarchiver ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; rm -rf common )
@@ -20,14 +30,24 @@
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/smbmounter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/imgallery ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/validators ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf qpl-license.html )
@@ -180,16 +200,26 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kicker-applets ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/uachanger ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kaphorism ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kaphorism ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/dirfilter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/dma ; rm -rf common )
@@ -216,3 +246,5 @@
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kate-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
